function dsr=ds_dT(T,P,vf)
% Compute derivative of entropy with respect to T
% T : Temperature [C]
% P : Pressure    [bar a]
% vf: Vapour fraction (1=vapour and 0=liquid)

R    = 8.314;                            % Gas constant          [kJ/(kmol*K)]
Tref = 273.15;                           % Reference temperature [K]
Pref = 1;                                % Reference pressure    [bar a]

HeatPropertyConstants;

% Gas properties 
dTp    =[T^4 T^3 T^2 T 1 T^-1]';

dsv=Cpv*dTp;

dsvCmp=[dsv(1) (dsv(2)+dsv(3)+dsv(4))/3 dsv(6) dsv(7) dsv(8)]';

%Values to be computed later??
dsl=0;

dsr=[(1-vf)*dsl + vf*dsvCmp];           % [J/mol/K]
return

